@@ -1,4 +1,4 @@
-/* $Id: cdkselection.c,v 1.16 2019/02/20 02:13:25 tom Exp $ */
+/* $Id: cdkselection.c,v 1.18 2025/01/09 00:20:21 tom Exp $ */
 
 #include <cdk_test.h>
 
@@ -22,23 +22,23 @@ static const char *FPUsage = "-l List | -f filename [-c Choices ] [-s Selection
 int main (int argc, char **argv)
 {
    /* *INDENT-EQLS* */
-   CDKSCREEN *cdkScreen         = 0;
-   CDKSELECTION *widget         = 0;
-   CDKBUTTONBOX *buttonWidget   = 0;
-   chtype *holder               = 0;
-   char *item                   = 0;
-   char *CDK_WIDGET_COLOR       = 0;
-   char *temp                   = 0;
+   CDKSCREEN *cdkScreen         = NULL;
+   CDKSELECTION *widget         = NULL;
+   CDKBUTTONBOX *buttonWidget   = NULL;
+   chtype *holder               = NULL;
+   char *item                   = NULL;
+   char *CDK_WIDGET_COLOR       = NULL;
+   char *temp                   = NULL;
    int scrollLines              = -1;
    int choiceSize               = -1;
    int buttonCount              = 0;
    int selection                = 0;
    int shadowHeight             = 0;
    FILE *fp                     = stderr;
-   char **scrollList            = 0;
-   char **choiceList            = 0;
-   char **buttonList            = 0;
-   char **items                 = 0;
+   char **scrollList            = NULL;
+   char **choiceList            = NULL;
+   char **buttonList            = NULL;
+   char **items                 = NULL;
    int choiceValues[MAX_ITEMS];
    int editModes[MAX_ITEMS];
    int x, fields, j1, j2;
@@ -79,9 +79,9 @@ int main (int argc, char **argv)
    (void)numbers;
 
    /* If the user asked for an output file, try to open it. */
-   if (outputFile != 0)
+   if (outputFile != NULL)
    {
-      if ((fp = fopen (outputFile, "w")) == 0)
+      if ((fp = fopen (outputFile, "w")) == NULL)
       {
 	 fprintf (stderr, "%s: Can not open output file %s\n", argv[0], outputFile);
 	 ExitProgram (CLI_ERROR);
@@ -89,10 +89,10 @@ int main (int argc, char **argv)
    }
 
    /* Did they provide a list of items. */
-   if (list == 0)
+   if (list == NULL)
    {
       /* Maybe they gave a filename to use to read. */
-      if (filename != 0)
+      if (filename != NULL)
       {
 	 /* Read the file in. */
 	 scrollLines = CDKreadFile (filename, &scrollList);
@@ -156,9 +156,9 @@ int main (int argc, char **argv)
    }
 
    /* Did they supply a choice list. */
-   if (choices == 0)
+   if (choices == NULL)
    {
-      choiceList = calloc(sizeof (char *), 3);
+      choiceList = calloc(3, sizeof (char *));
       choiceList[0] = copyChar ("Yes ");
       choiceList[1] = copyChar ("No ");
       choiceSize = 2;
@@ -176,7 +176,7 @@ int main (int argc, char **argv)
    initCDKColor ();
 
    /* Check if the user wants to set the background of the main screen. */
-   if ((temp = getenv ("CDK_SCREEN_COLOR")) != 0)
+   if ((temp = getenv ("CDK_SCREEN_COLOR")) != NULL)
    {
       holder = char2Chtype (temp, &j1, &j2);
       wbkgd (cdkScreen->window, holder[0]);
@@ -185,9 +185,9 @@ int main (int argc, char **argv)
    }
 
    /* Get the widget color background color. */
-   if ((CDK_WIDGET_COLOR = getenv ("CDK_WIDGET_COLOR")) == 0)
+   if ((CDK_WIDGET_COLOR = getenv ("CDK_WIDGET_COLOR")) == NULL)
    {
-      CDK_WIDGET_COLOR = 0;
+      CDK_WIDGET_COLOR = NULL;
    }
 
    /* Create the scrolling list. */
@@ -200,7 +200,7 @@ int main (int argc, char **argv)
    CDKfreeStrings (choiceList);
 
    /* Make sure we could create the widget. */
-   if (widget == 0)
+   if (widget == NULL)
    {
       CDKfreeStrings (scrollList);
 
@@ -218,7 +218,7 @@ int main (int argc, char **argv)
    setCDKSelectionChoices (widget, choiceValues);
 
    /* Split the buttons if they supplied some. */
-   if (buttons != 0)
+   if (buttons != NULL)
    {
       /* Split the button list up. */
       buttonList = CDKsplitString (buttons, '\n');
@@ -230,7 +230,7 @@ int main (int argc, char **argv)
 				      (getbegy (widget->win)
 				       + widget->boxHeight - 1),
 				      1, widget->boxWidth - 1,
-				      0, 1, buttonCount,
+				      NULL, 1, buttonCount,
 				      (CDK_CSTRING2)buttonList, buttonCount,
 				      A_REVERSE, boxWidget, FALSE);
       CDKfreeStrings (buttonList);
@@ -271,7 +271,7 @@ int main (int argc, char **argv)
    if (shadowWidget == TRUE)
    {
       /* Determine the height of the shadow window. */
-      shadowHeight = (buttonWidget == 0 ?
+      shadowHeight = (buttonWidget == NULL ?
 		      widget->boxHeight :
 		      widget->boxHeight + buttonWidget->boxHeight - 1);
 
@@ -282,7 +282,7 @@ int main (int argc, char **argv)
 				  getbegx (widget->win) + 1);
 
       /* Make sure we could have created the shadow window. */
-      if (widget->shadowWin != 0)
+      if (widget->shadowWin != NULL)
       {
 	 widget->shadow = TRUE;
 
@@ -304,10 +304,10 @@ int main (int argc, char **argv)
    setCDKSelectionModes (widget, editModes);
 
    /* Activate the selection list. */
-   activateCDKSelection (widget, 0);
+   activateCDKSelection (widget, NULL);
 
    /* If there were buttons, get the button selected. */
-   if (buttonWidget != 0)
+   if (buttonWidget != NULL)
    {
       selection = buttonWidget->currentButton;
       destroyCDKButtonbox (buttonWidget);
