@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: template.sh,v 1.3 2005/12/27 15:53:06 tom Exp $
+# $Id: template.sh,v 1.4 2022/10/18 23:55:40 tom Exp $
 
 #
 # Description:
@@ -27,29 +27,31 @@ buttons=" OK
 #
 # Create the template box.
 #
-${CDK_TEMPLATE} -p "###.###.###.###" -o "___.___.___.___" -T "${title}" -P -B "${buttons}" 2> ${output}
+${CDK_TEMPLATE} -p "###.###.###.###" -o "___.___.___.___" -T "${title}" -P -B "${buttons}" 2> "${output}"
 selected=$?
 test $selected = 255 && exit 1
 
-answer=`cat ${output}`
+answer=`cat "${output}"`
 
 #
 # Create the message for the label widget.
 #
-echo "<C>Here is the IP you typed in" > ${tmp}
-echo " " >> ${tmp}
-echo "<C></R>${answer}" >> ${tmp}
-echo " " >> ${tmp}
-echo "<C>You chose button #${selected}" >> ${tmp}
-echo " " >> ${tmp}
-echo "<C>Hit </R>space<!R> to continue." >> ${tmp}
+cat >"${tmp}" <<EOF
+<C>Here is the IP you typed in
+
+<C></R>${answer}
+
+<C>You chose button #${selected}
+
+<C>Hit </R>space<!R> to continue.
+EOF
 
 #
 # Create the label widget to display the information.
 #
-${CDK_LABEL} -f ${tmp} -p " "
+${CDK_LABEL} -f "${tmp}" -p " "
 
 #
 # Clean up.
 #
-rm -f ${tmp} ${output}
+rm -f "${tmp}" "${output}"
