@@ -1,4 +1,4 @@
-/* $Id: menu_ex.c,v 1.12 2012/03/21 23:26:05 tom Exp $ */
+/* $Id: menu_ex.c,v 1.14 2025/01/09 00:20:21 tom Exp $ */
 
 #include <cdk_test.h>
 
@@ -37,18 +37,15 @@ static const char *menuInfo[3][4] =
 int main (void)
 {
    /* *INDENT-EQLS* */
-   CDKSCREEN *cdkscreen = 0;
-   CDKLABEL *infoBox    = 0;
-   CDKMENU *menu        = 0;
-   WINDOW *cursesWin    = 0;
+   CDKSCREEN *cdkscreen = NULL;
+   CDKLABEL *infoBox    = NULL;
+   CDKMENU *menu        = NULL;
    int submenusize[3], menuloc[4];
    const char *mesg[5];
    char temp[256];
    int selection;
 
-   /* Set up CDK. */
-   cursesWin = initscr ();
-   cdkscreen = initCDKScreen (cursesWin);
+   cdkscreen = initCDKScreen (NULL);
 
    /* Start CDK color. */
    initCDKColor ();
@@ -96,7 +93,7 @@ int main (void)
    refreshCDKScreen (cdkscreen);
 
    /* Activate the menu. */
-   selection = activateCDKMenu (menu, 0);
+   selection = activateCDKMenu (menu, NULL);
 
    /* Determine how the user exited from the widget. */
    if (menu->exitType == vEARLY_EXIT)
