@@ -1,5 +1,5 @@
 /*
- * $Id: cdk_util.h,v 1.35 2014/01/19 01:58:31 tom Exp $
+ * $Id: cdk_util.h,v 1.39 2025/01/14 08:58:34 tom Exp $
  */
 
 #ifndef CDKINCLUDES
@@ -19,38 +19,31 @@ extern "C" {
 #endif
 
 /*
- * Changes 1999-2012,2014 copyright Thomas E. Dickey
- *
+ * Changes 1999-2024,2025 copyright Thomas E. Dickey
  * Copyright 1999, Mike Glover
- * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgment:
- *      This product includes software developed by Mike Glover
- *      and contributors.
- * 4. Neither the name of Mike Glover, nor the names of contributors
- *    may be used to endorse or promote products derived from this software
- *    without specific prior written permission.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to
+ * deal in the Software without restriction, including without limitation the
+ * rights to use, copy, modify, merge, publish, distribute, distribute with
+ * modifications, sublicense, and/or sell copies of the Software, and to permit
+ * persons to whom the Software is furnished to do so, subject to the following
+ * conditions:
  *
- * THIS SOFTWARE IS PROVIDED BY MIKE GLOVER AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL MIKE GLOVER OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+ * ABOVE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+ * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
+ * IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
+ *
+ * Except as contained in this notice, the name(s) of the above copyright
+ * holders shall not be used in advertising or otherwise to promote the sale,
+ * use or other dealings in this Software without prior written authorization.
  */
 
 /*
@@ -162,6 +155,19 @@ void sortList (
 		CDK_CSTRING *	/* list */,
 		int		/* length */);
 
+/*
+ * This changes to a new working directory, possibly expanding "~", etc.
+ */
+int CDKchdir (
+		const char *	/* filename */);
+
+/*
+ * This opens a file with the given mode, possibly expanding "~", etc.
+ */
+FILE * CDKopenFile (
+		const char *	/* filename */,
+		const char *	/* mode */);
+
 /*
  * This reads a file, loads the contents into info and
  * returns the number of lines read.
@@ -404,6 +410,13 @@ int setWidgetDimension (
 		int		/* proposedDim */,
 		int		/* adjustment */);
 
+/*
+ * This disables/re-enables conversion of embedded markup in strings to
+ * curses attributes.
+ */
+void enableCursesMarkup (
+		boolean		/* flag */);
+
 /*
  * This safely erases a given window.
  */
